<template>
  <div>
    <el-form label-width="80px" size="small" @submit.native.prevent>
      <el-form-item label="流程表单">
        <el-select v-model="bpmnFormData.formKey" clearable class="m-2" placeholder="挂载节点表单" @clear="updateElementFormKey(null)" @change="updateElementFormKey">
          <el-option
              v-for="item in formList"
              :key="item.formId"
              :label="item.formName"
              :value="item.formId"
          />
        </el-select>
      </el-form-item>
    </el-form>
  </div>
</template>

<script>

import { listAllForm } from '@/api/flowable/form'
import {StrUtil} from "@/utils/StrUtil";
export default {
  name: "FormPanel",
  /** 组件传值  */
  props : {
    id: {
      type: String,
      required: true
    },
  },
  data() {
    return {
      formList: [], // 表单数据
      bpmnFormData: {}
    }
  },

  /** 传值监听 */
  watch: {
    id: {
      handler(newVal) {
        console.log("新的id值：", newVal)
        if (StrUtil.isNotBlank(newVal)) {
          this.init()
        }
      },
      immediate: true, // 立即生效
    },
  },
  created() {

  },
  methods: {
    init() {
      // 加载表单列表
      this.getListForm();
      this.resetFlowForm();
    },
    // 方法区
    resetFlowForm() {
      this.bpmnFormData.formKey = this.modelerStore.element.businessObject.formKey;
      console.log(this.bpmnFormData.formKey, "formKey!!")
    },

    updateElementFormKey(val) {
      console.log(val, "数据改变")
      console.log(this.bpmnFormData.formKey, "数据改变")
      this.init()
      if (StrUtil.isBlank(val)) {
        delete this.modelerStore.element.businessObject[`formKey`]
      } else {
        this.modelerStore.modeling.updateProperties(this.modelerStore.element, {'formKey': val});
      }
    },

    // 获取表单信息
    getListForm() {
      listAllForm().then(res => {
        res.data.forEach(item => {
          item.formId = item.formId.toString();
        })
        this.formList = res.data;
        console.log("表单信息：", this.formList)
      })
    }
  }
}


</script>
